==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/IrkModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.IrkAnimation;
import net.invictusslayer.slayersbeasts.world.entity.Irk;
import net.minecraft.class_2960;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class IrkModel<T extends Irk> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "irk_model"), "main");
	private final class_630 root;

	public IrkModel(class_630 root) {
		this.root = root;
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		method_48741(IrkAnimation.WALK, limbSwing, limbSwingAmount, 15, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 0).method_32098(-1.5F, 0.0F, -1.0F, 3.0F, 12.0F, 3.0F, new class_5605(0.0F))
				.method_32101(0, 12).method_32098(0.0F, 0.5F, 2.0F, 0.0F, 12.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 5.0F, -2.0F, 0.7854F, 0.0F, 0.0F));

		class_5610 upper = body.method_32117("upper", class_5606.method_32108().method_32101(43, 6).method_32098(2.0F, -5.5F, -3.5F, 2.0F, 4.0F, 3.0F, new class_5605(0.0F))
				.method_32101(40, 42).method_32098(-4.0F, -5.5F, -3.5F, 2.0F, 4.0F, 3.0F, new class_5605(0.0F))
				.method_32101(8, 11).method_32098(-2.0F, -6.0F, -4.0F, 4.0F, 6.0F, 4.0F, new class_5605(0.0F))
				.method_32101(24, 32).method_32098(0.0F, -5.75F, 0.0F, 0.0F, 7.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 2.0F, 0.4363F, 0.0F, 0.0F));

		class_5610 neck = upper.method_32117("neck", class_5606.method_32108().method_32101(47, 39).method_32098(-1.0F, -2.0F, 0.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -6.0F, -2.75F, -0.8727F, 0.0F, 0.0F));

		class_5610 head = neck.method_32117("head", class_5606.method_32108().method_32101(20, 8).method_32098(-2.5F, -5.75F, -2.0F, 5.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(42, 0).method_32098(-1.5F, -5.0F, 2.0F, 3.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(12, 0).method_32098(-1.5F, -4.0F, -4.0F, 3.0F, 2.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 0.0F, 0.0F));

		class_5610 horn_left = head.method_32117("horn_left", class_5606.method_32108().method_32101(9, 29).method_32098(-1.0F, -2.0F, -1.0F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(12, 0).method_32098(-0.5F, -4.0F, -0.5F, 0.0F, 2.0F, 3.0F, new class_5605(0.0F))
				.method_32101(9, 0).method_32098(-0.5F, -3.0F, 2.5F, 0.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -4.75F, 0.5F, 0.0F, 0.0F, 0.4363F));

		class_5610 horn_right = head.method_32117("horn_right", class_5606.method_32108().method_32101(48, 26).method_32098(0.0F, -2.0F, -1.0F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(12, 5).method_32098(0.5F, -4.0F, -0.5F, 0.0F, 2.0F, 3.0F, new class_5605(0.0F))
				.method_32101(12, 3).method_32098(0.5F, -3.0F, 2.5F, 0.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -4.75F, 0.5F, 0.0F, 0.0F, -0.4363F));

		class_5610 arm_left = upper.method_32117("arm_left", class_5606.method_32108().method_32101(0, 37).method_32098(0.0F, -1.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, -4.0F, -2.0F, -0.9163F, 0.0F, 0.0F));

		class_5610 l_11 = arm_left.method_32117("l_11", class_5606.method_32108().method_32101(34, 11).method_32098(-0.999F, 0.0F, -1.75F, 2.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 21).method_32098(-0.999F, 0.25F, -7.75F, 2.0F, 2.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 6.5F, -1.0F, -0.5672F, 0.0F, 0.0F));

		class_5610 hand_left = l_11.method_32117("hand_left", class_5606.method_32108().method_32101(10, 33).method_32098(-1.499F, -0.5F, -3.5F, 3.0F, 2.0F, 4.0F, new class_5605(0.0F))
				.method_32101(8, 45).method_32098(1.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(44, 18).method_32098(0.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 44).method_32098(-0.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(28, 41).method_32098(-1.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.5F, -7.25F, 1.0472F, 0.0F, 0.0F));

		class_5610 arm_right = upper.method_32117("arm_right", class_5606.method_32108().method_32101(35, 34).method_32098(-2.0F, -1.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, -4.0F, -2.0F, -0.9163F, 0.0F, 0.0F));

		class_5610 r_11 = arm_right.method_32117("r_11", class_5606.method_32108().method_32101(34, 2).method_32098(-0.999F, 0.0F, -1.75F, 2.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(18, 15).method_32098(-0.999F, 0.25F, -7.75F, 2.0F, 2.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 6.5F, -1.0F, -0.5672F, 0.0F, 0.0F));

		class_5610 hand_right = r_11.method_32117("hand_right", class_5606.method_32108().method_32101(24, 0).method_32098(-1.499F, -0.5F, -3.5F, 3.0F, 2.0F, 4.0F, new class_5605(0.0F))
				.method_32101(41, 14).method_32098(1.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(8, 41).method_32098(0.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(16, 35).method_32098(-0.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(10, 17).method_32098(-1.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.5F, -7.25F, 1.0472F, 0.0F, 0.0F));

		class_5610 leg_left = body.method_32117("leg_left", class_5606.method_32108().method_32101(32, 20).method_32098(0.0F, -5.0F, -3.0F, 3.0F, 7.0F, 3.0F, new class_5605(0.0F))
				.method_32101(35, 48).method_32098(0.5F, -4.5F, 0.0F, 2.0F, 6.0F, 1.0F, new class_5605(0.0F))
				.method_32101(43, 32).method_32098(0.0F, -5.0F, -5.0F, 3.0F, 5.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 10.0F, 0.5F, 0.48F, 0.0F, 0.0F));

		class_5610 l_21 = leg_left.method_32117("l_21", class_5606.method_32108().method_32101(48, 2).method_32098(-0.501F, 0.0F, -7.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 29).method_32098(-0.501F, 0.0F, -5.0F, 2.0F, 3.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -5.0F, -5.0F, 0.829F, 0.0F, 0.0F));

		class_5610 hoof_left = l_21.method_32117("hoof_left", class_5606.method_32108().method_32101(40, 26).method_32098(-1.0F, -2.0F, -4.0F, 2.0F, 2.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, 2.0F, -7.0F, -0.5236F, 0.0F, 0.0F));

		class_5610 leg_right = body.method_32117("leg_right", class_5606.method_32108().method_32101(16, 23).method_32098(-3.0F, -5.0F, -3.0F, 3.0F, 7.0F, 3.0F, new class_5605(0.0F))
				.method_32101(49, 13).method_32098(-2.5F, -4.5F, 0.0F, 2.0F, 6.0F, 1.0F, new class_5605(0.0F))
				.method_32101(18, 43).method_32098(-3.0F, -5.0F, -5.0F, 3.0F, 5.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 10.0F, 0.5F, 0.48F, 0.0F, 0.0F));

		class_5610 r_21 = leg_right.method_32117("r_21", class_5606.method_32108().method_32101(28, 16).method_32098(-0.499F, 0.0F, -7.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(23, 28).method_32098(-0.499F, 0.0F, -5.0F, 2.0F, 3.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -5.0F, -5.0F, 0.829F, 0.0F, 0.0F));

		class_5610 hoof_right = r_21.method_32117("hoof_right", class_5606.method_32108().method_32101(8, 39).method_32098(-1.0F, -2.0F, -4.0F, 2.0F, 2.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, 2.0F, -7.0F, -0.5236F, 0.0F, 0.0F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/IrkModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.IrkAnimation;
import net.minecraft.class_10042;
import net.minecraft.class_2960;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class IrkModel extends class_583<class_10042> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "irk_model"), "main");

	public IrkModel(class_630 root) {
		super(root);
	}

	public void setupAnim(class_10042 state) {
		super.method_2819(state);
		method_62102(IrkAnimation.WALK, state.field_53450, state.field_53451, 15, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 0).method_32098(-1.5F, 0.0F, -1.0F, 3.0F, 12.0F, 3.0F, new class_5605(0.0F))
				.method_32101(0, 12).method_32098(0.0F, 0.5F, 2.0F, 0.0F, 12.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 5.0F, -2.0F, 0.7854F, 0.0F, 0.0F));

		class_5610 upper = body.method_32117("upper", class_5606.method_32108().method_32101(43, 6).method_32098(2.0F, -5.5F, -3.5F, 2.0F, 4.0F, 3.0F, new class_5605(0.0F))
				.method_32101(40, 42).method_32098(-4.0F, -5.5F, -3.5F, 2.0F, 4.0F, 3.0F, new class_5605(0.0F))
				.method_32101(8, 11).method_32098(-2.0F, -6.0F, -4.0F, 4.0F, 6.0F, 4.0F, new class_5605(0.0F))
				.method_32101(24, 32).method_32098(0.0F, -5.75F, 0.0F, 0.0F, 7.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 2.0F, 0.4363F, 0.0F, 0.0F));

		class_5610 neck = upper.method_32117("neck", class_5606.method_32108().method_32101(47, 39).method_32098(-1.0F, -2.0F, 0.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -6.0F, -2.75F, -0.8727F, 0.0F, 0.0F));

		class_5610 head = neck.method_32117("head", class_5606.method_32108().method_32101(20, 8).method_32098(-2.5F, -5.75F, -2.0F, 5.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(42, 0).method_32098(-1.5F, -5.0F, 2.0F, 3.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(12, 0).method_32098(-1.5F, -4.0F, -4.0F, 3.0F, 2.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 0.0F, 0.0F));

		class_5610 horn_left = head.method_32117("horn_left", class_5606.method_32108().method_32101(9, 29).method_32098(-1.0F, -2.0F, -1.0F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(12, 0).method_32098(-0.5F, -4.0F, -0.5F, 0.0F, 2.0F, 3.0F, new class_5605(0.0F))
				.method_32101(9, 0).method_32098(-0.5F, -3.0F, 2.5F, 0.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -4.75F, 0.5F, 0.0F, 0.0F, 0.4363F));

		class_5610 horn_right = head.method_32117("horn_right", class_5606.method_32108().method_32101(48, 26).method_32098(0.0F, -2.0F, -1.0F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(12, 5).method_32098(0.5F, -4.0F, -0.5F, 0.0F, 2.0F, 3.0F, new class_5605(0.0F))
				.method_32101(12, 3).method_32098(0.5F, -3.0F, 2.5F, 0.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -4.75F, 0.5F, 0.0F, 0.0F, -0.4363F));

		class_5610 arm_left = upper.method_32117("arm_left", class_5606.method_32108().method_32101(0, 37).method_32098(0.0F, -1.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, -4.0F, -2.0F, -0.9163F, 0.0F, 0.0F));

		class_5610 l_11 = arm_left.method_32117("l_11", class_5606.method_32108().method_32101(34, 11).method_32098(-0.999F, 0.0F, -1.75F, 2.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 21).method_32098(-0.999F, 0.25F, -7.75F, 2.0F, 2.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 6.5F, -1.0F, -0.5672F, 0.0F, 0.0F));

		class_5610 hand_left = l_11.method_32117("hand_left", class_5606.method_32108().method_32101(10, 33).method_32098(-1.499F, -0.5F, -3.5F, 3.0F, 2.0F, 4.0F, new class_5605(0.0F))
				.method_32101(8, 45).method_32098(1.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(44, 18).method_32098(0.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 44).method_32098(-0.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(28, 41).method_32098(-1.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.5F, -7.25F, 1.0472F, 0.0F, 0.0F));

		class_5610 arm_right = upper.method_32117("arm_right", class_5606.method_32108().method_32101(35, 34).method_32098(-2.0F, -1.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, -4.0F, -2.0F, -0.9163F, 0.0F, 0.0F));

		class_5610 r_11 = arm_right.method_32117("r_11", class_5606.method_32108().method_32101(34, 2).method_32098(-0.999F, 0.0F, -1.75F, 2.0F, 3.0F, 4.0F, new class_5605(0.0F))
				.method_32101(18, 15).method_32098(-0.999F, 0.25F, -7.75F, 2.0F, 2.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 6.5F, -1.0F, -0.5672F, 0.0F, 0.0F));

		class_5610 hand_right = r_11.method_32117("hand_right", class_5606.method_32108().method_32101(24, 0).method_32098(-1.499F, -0.5F, -3.5F, 3.0F, 2.0F, 4.0F, new class_5605(0.0F))
				.method_32101(41, 14).method_32098(1.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(8, 41).method_32098(0.501F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(16, 35).method_32098(-0.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F))
				.method_32101(10, 17).method_32098(-1.499F, -0.5F, -7.5F, 0.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.5F, -7.25F, 1.0472F, 0.0F, 0.0F));

		class_5610 leg_left = body.method_32117("leg_left", class_5606.method_32108().method_32101(32, 20).method_32098(0.0F, -5.0F, -3.0F, 3.0F, 7.0F, 3.0F, new class_5605(0.0F))
				.method_32101(35, 48).method_32098(0.5F, -4.5F, 0.0F, 2.0F, 6.0F, 1.0F, new class_5605(0.0F))
				.method_32101(43, 32).method_32098(0.0F, -5.0F, -5.0F, 3.0F, 5.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 10.0F, 0.5F, 0.48F, 0.0F, 0.0F));

		class_5610 l_21 = leg_left.method_32117("l_21", class_5606.method_32108().method_32101(48, 2).method_32098(-0.501F, 0.0F, -7.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 29).method_32098(-0.501F, 0.0F, -5.0F, 2.0F, 3.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -5.0F, -5.0F, 0.829F, 0.0F, 0.0F));

		class_5610 hoof_left = l_21.method_32117("hoof_left", class_5606.method_32108().method_32101(40, 26).method_32098(-1.0F, -2.0F, -4.0F, 2.0F, 2.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, 2.0F, -7.0F, -0.5236F, 0.0F, 0.0F));

		class_5610 leg_right = body.method_32117("leg_right", class_5606.method_32108().method_32101(16, 23).method_32098(-3.0F, -5.0F, -3.0F, 3.0F, 7.0F, 3.0F, new class_5605(0.0F))
				.method_32101(49, 13).method_32098(-2.5F, -4.5F, 0.0F, 2.0F, 6.0F, 1.0F, new class_5605(0.0F))
				.method_32101(18, 43).method_32098(-3.0F, -5.0F, -5.0F, 3.0F, 5.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 10.0F, 0.5F, 0.48F, 0.0F, 0.0F));

		class_5610 r_21 = leg_right.method_32117("r_21", class_5606.method_32108().method_32101(28, 16).method_32098(-0.499F, 0.0F, -7.0F, 2.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(23, 28).method_32098(-0.499F, 0.0F, -5.0F, 2.0F, 3.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -5.0F, -5.0F, 0.829F, 0.0F, 0.0F));

		class_5610 hoof_right = r_21.method_32117("hoof_right", class_5606.method_32108().method_32101(8, 39).method_32098(-1.0F, -2.0F, -4.0F, 2.0F, 2.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.5F, 2.0F, -7.0F, -0.5236F, 0.0F, 0.0F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}
